@@ -6,32 +6,32 @@ TODO:
 """
 
 from __future__ import unicode_literals
-from pkg_resources import Requirement, resource_filename
 
-import os
-import sys
+import argparse
 import glob
 import logging
-import argparse
+import os
+import sys
 import warnings
 
-from pymatgen.io.vasp.outputs import BSVasprun
-from pymatgen.electronic_structure.core import Spin
-from pymatgen.electronic_structure.bandstructure import \
-    get_reconstructed_band_structure
-
 import matplotlib as mpl
-mpl.use('Agg')
+from pkg_resources import Requirement, resource_filename
+from pymatgen.electronic_structure.bandstructure import get_reconstructed_band_structure
+from pymatgen.electronic_structure.core import Spin
+from pymatgen.io.vasp.outputs import BSVasprun
 
-from sumo.io.questaal import QuestaalSite, labels_from_syml
-from sumo.io.questaal import band_structure as questaal_band_structure
+mpl.use("Agg")
+
+from sumo.cli.dosplot import _atoms, _el_orb
+from sumo.electronic_structure.bandstructure import string_to_spin
+from sumo.electronic_structure.dos import load_dos
 from sumo.io.castep import band_structure as castep_band_structure
 from sumo.io.castep import read_dos as read_castep_dos
+from sumo.io.questaal import QuestaalSite
+from sumo.io.questaal import band_structure as questaal_band_structure
+from sumo.io.questaal import labels_from_syml
 from sumo.plotting.bs_plotter import SBSPlotter
 from sumo.plotting.dos_plotter import SDOSPlotter
-from sumo.electronic_structure.dos import load_dos
-from sumo.electronic_structure.bandstructure import string_to_spin
-from sumo.cli.dosplot import _atoms, _el_orb
 
 try:
     import configparser
@@ -45,17 +45,43 @@ __email__ = "alexganose@googlemail.com"
 __date__ = "July 18, 2017"
 
 
-def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
-             vbm_cbm_marker=False, projection_selection=None, mode='rgb',
-             normalise="all",
-             interpolate_factor=4, circle_size=150, dos_file=None,
-             cart_coords=False, scissor=None,
-             ylabel='Energy (eV)', dos_label=None,
-             elements=None, lm_orbitals=None, atoms=None, spin=None,
-             total_only=False, plot_total=True, legend_cutoff=3, gaussian=None,
-             height=None, width=None, ymin=-6., ymax=6., colours=None,
-             yscale=1, style=None, no_base_style=False,
-             image_format='pdf', dpi=400, plt=None, fonts=None):
+def bandplot(
+    filenames=None,
+    code="vasp",
+    prefix=None,
+    directory=None,
+    vbm_cbm_marker=False,
+    projection_selection=None,
+    mode="rgb",
+    normalise="all",
+    interpolate_factor=4,
+    circle_size=150,
+    dos_file=None,
+    cart_coords=False,
+    scissor=None,
+    ylabel="Energy (eV)",
+    dos_label=None,
+    elements=None,
+    lm_orbitals=None,
+    atoms=None,
+    spin=None,
+    total_only=False,
+    plot_total=True,
+    legend_cutoff=3,
+    gaussian=None,
+    height=None,
+    width=None,
+    ymin=-6.0,
+    ymax=6.0,
+    colours=None,
+    yscale=1,
+    style=None,
+    no_base_style=False,
+    image_format="pdf",
+    dpi=400,
+    plt=None,
+    fonts=None,
+):
     """Plot electronic band structure diagrams from vasprun.xml files.
 
     Args:
@@ -242,66 +268,73 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
     # now load all the band structure data and combine using the
     # get_reconstructed_band_structure function from pymatgen
     bandstructures = []
-    if code == 'vasp':
+    if code == "vasp":
         for vr_file in filenames:
             vr = BSVasprun(vr_file, parse_projected_eigen=parse_projected)
             bs = vr.get_band_structure(line_mode=True)
             bandstructures.append(bs)
         bs = get_reconstructed_band_structure(bandstructures)
-    elif code == 'castep':
+    elif code == "castep":
         for bands_file in filenames:
-            cell_file = _replace_ext(bands_file, 'cell')
+            cell_file = _replace_ext(bands_file, "cell")
             if os.path.isfile(cell_file):
-                logging.info('Found cell file {}...'.format(cell_file))
+                logging.info("Found cell file {}...".format(cell_file))
             else:
-                logging.info('Did not find cell file {}...'.format(cell_file))
+                logging.info("Did not find cell file {}...".format(cell_file))
                 cell_file = None
             bs = castep_band_structure(bands_file, cell_file=cell_file)
             bandstructures.append(bs)
         bs = get_reconstructed_band_structure(bandstructures)
-    elif code == 'questaal':
+    elif code == "questaal":
         bnds_file = filenames[0]
-        ext = bnds_file.split('.')[-1]
+        ext = bnds_file.split(".")[-1]
         bnds_folder = os.path.join(bnds_file, os.path.pardir)
 
-        site_file = os.path.abspath(
-            os.path.join(bnds_folder, 'site.{}'.format(ext)))
+        site_file = os.path.abspath(os.path.join(bnds_folder, "site.{}".format(ext)))
 
         if os.path.isfile(site_file):
-            logging.info('site file found, reading lattice...')
+            logging.info("site file found, reading lattice...")
             site_data = QuestaalSite.from_file(site_file)
             bnds_lattice = site_data.structure.lattice
             alat = site_data.alat
         else:
-            raise IOError('Site file {} not found: '
-                          'needed to determine lattice'.format(site_file))
+            raise IOError(
+                "Site file {} not found: "
+                "needed to determine lattice".format(site_file)
+            )
 
-        syml_file = os.path.abspath(
-            os.path.join(bnds_folder, 'syml.{}'.format(ext)))
+        syml_file = os.path.abspath(os.path.join(bnds_folder, "syml.{}".format(ext)))
         if os.path.isfile(syml_file):
-            logging.info('syml file found, reading special-point labels...')
+            logging.info("syml file found, reading special-point labels...")
             bnds_labels = labels_from_syml(syml_file)
         else:
-            logging.info('syml file not found, band structure lacks labels')
+            logging.info("syml file not found, band structure lacks labels")
             bnds_labels = {}
 
-        bs = questaal_band_structure(bnds_file, bnds_lattice, alat=alat,
-                                     labels=bnds_labels,
-                                     coords_are_cartesian=cart_coords)
+        bs = questaal_band_structure(
+            bnds_file,
+            bnds_lattice,
+            alat=alat,
+            labels=bnds_labels,
+            coords_are_cartesian=cart_coords,
+        )
 
     # currently not supported as it is a pain to make subplots within subplots,
     # although need to check this is still the case
-    if 'split' in mode and dos_file:
-        logging.error('ERROR: Plotting split projected band structure with DOS'
-                      ' not supported.\nPlease use --projected-rgb or '
-                      '--projected-stacked options.')
+    if "split" in mode and dos_file:
+        logging.error(
+            "ERROR: Plotting split projected band structure with DOS"
+            " not supported.\nPlease use --projected-rgb or "
+            "--projected-stacked options."
+        )
         sys.exit()
 
-    if (projection_selection and mode == 'rgb'
-            and len(projection_selection) > 3):
-        logging.error('ERROR: RGB projected band structure only '
-                      'supports up to 3 elements/orbitals.'
-                      '\nUse alternative --mode setting.')
+    if projection_selection and mode == "rgb" and len(projection_selection) > 3:
+        logging.error(
+            "ERROR: RGB projected band structure only "
+            "supports up to 3 elements/orbitals."
+            "\nUse alternative --mode setting."
+        )
         sys.exit()
 
     # don't save if pyplot object provided
@@ -310,33 +343,44 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
     dos_plotter = None
     dos_opts = None
     if dos_file:
-        if code == 'vasp':
-            dos, pdos = load_dos(dos_file, elements, lm_orbitals,
-                                 atoms, gaussian, total_only)
-        elif code == 'castep':
+        if code == "vasp":
+            dos, pdos = load_dos(
+                dos_file, elements, lm_orbitals, atoms, gaussian, total_only
+            )
+        elif code == "castep":
             pdos_file = None
             if cell_file:
-                pdos_file = _replace_ext(cell_file, 'pdos_bin')
+                pdos_file = _replace_ext(cell_file, "pdos_bin")
                 if not os.path.isfile(pdos_file):
                     pdos_file = None
-                    logging.info(f"PDOS file {pdos_file} does not exist, "
-                                 "falling back to TDOS.")
+                    logging.info(
+                        f"PDOS file {pdos_file} does not exist, "
+                        "falling back to TDOS."
+                    )
                 else:
                     logging.info(f"Found PDOS file {pdos_file}")
             else:
-                logging.info(f"Cell file {cell_file} does not exist, "
-                             "cannot plot PDOS.")
+                logging.info(
+                    f"Cell file {cell_file} does not exist, " "cannot plot PDOS."
+                )
 
-            dos, pdos = read_castep_dos(dos_file, pdos_file=pdos_file,
-                                        cell_file=cell_file,
-                                        gaussian=gaussian,
-                                        lm_orbitals=lm_orbitals,
-                                        elements=elements,
-                                        efermi_to_vbm=True)
+            dos, pdos = read_castep_dos(
+                dos_file,
+                pdos_file=pdos_file,
+                cell_file=cell_file,
+                gaussian=gaussian,
+                lm_orbitals=lm_orbitals,
+                elements=elements,
+                efermi_to_vbm=True,
+            )
 
         dos_plotter = SDOSPlotter(dos, pdos)
-        dos_opts = {'plot_total': plot_total, 'legend_cutoff': legend_cutoff,
-                    'colours': colours, 'yscale': yscale}
+        dos_opts = {
+            "plot_total": plot_total,
+            "legend_cutoff": legend_cutoff,
+            "colours": colours,
+            "yscale": yscale,
+        }
 
     if scissor:
         bs = bs.apply_scissor(scissor)
@@ -345,32 +389,55 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
     plotter = SBSPlotter(bs)
     if projection_selection:
         plt = plotter.get_projected_plot(
-            projection_selection, mode=mode, normalise=normalise,
-            interpolate_factor=interpolate_factor, circle_size=circle_size,
-            zero_to_efermi=True, ymin=ymin, ymax=ymax, height=height,
-            width=width, vbm_cbm_marker=vbm_cbm_marker, ylabel=ylabel,
-            plt=plt, dos_plotter=dos_plotter, dos_options=dos_opts,
-            dos_label=dos_label, fonts=fonts, style=style,
-            no_base_style=no_base_style, spin=spin)
+            projection_selection,
+            mode=mode,
+            normalise=normalise,
+            interpolate_factor=interpolate_factor,
+            circle_size=circle_size,
+            zero_to_efermi=True,
+            ymin=ymin,
+            ymax=ymax,
+            height=height,
+            width=width,
+            vbm_cbm_marker=vbm_cbm_marker,
+            ylabel=ylabel,
+            plt=plt,
+            dos_plotter=dos_plotter,
+            dos_options=dos_opts,
+            dos_label=dos_label,
+            fonts=fonts,
+            style=style,
+            no_base_style=no_base_style,
+            spin=spin,
+        )
     else:
         plt = plotter.get_plot(
-            zero_to_efermi=True, ymin=ymin, ymax=ymax, height=height,
-            width=width, vbm_cbm_marker=vbm_cbm_marker, ylabel=ylabel,
-            plt=plt, dos_plotter=dos_plotter, dos_options=dos_opts,
-            dos_label=dos_label, fonts=fonts, style=style,
-            no_base_style=no_base_style, spin=spin)
+            zero_to_efermi=True,
+            ymin=ymin,
+            ymax=ymax,
+            height=height,
+            width=width,
+            vbm_cbm_marker=vbm_cbm_marker,
+            ylabel=ylabel,
+            plt=plt,
+            dos_plotter=dos_plotter,
+            dos_options=dos_opts,
+            dos_label=dos_label,
+            fonts=fonts,
+            style=style,
+            no_base_style=no_base_style,
+            spin=spin,
+        )
 
     if save_files:
-        basename = 'band.{}'.format(image_format)
-        filename = '{}_{}'.format(prefix, basename) if prefix else basename
+        basename = "band.{}".format(image_format)
+        filename = "{}_{}".format(prefix, basename) if prefix else basename
         if directory:
             filename = os.path.join(directory, filename)
-        plt.savefig(filename, format=image_format, dpi=dpi,
-                    bbox_inches='tight')
+        plt.savefig(filename, format=image_format, dpi=dpi, bbox_inches="tight")
 
         written = [filename]
-        written += save_data_files(bs, prefix=prefix,
-                                   directory=directory)
+        written += save_data_files(bs, prefix=prefix, directory=directory)
         return written
 
     else:
@@ -388,20 +455,20 @@ def find_vasprun_files():
     The split folder names should always be zero based, therefore easily
     sortable.
     """
-    folders = glob.glob('split-*')
-    folders = sorted(folders) if folders else ['.']
+    folders = glob.glob("split-*")
+    folders = sorted(folders) if folders else ["."]
 
     filenames = []
     for fol in folders:
-        vr_file = os.path.join(fol, 'vasprun.xml')
-        vr_file_gz = os.path.join(fol, 'vasprun.xml.gz')
+        vr_file = os.path.join(fol, "vasprun.xml")
+        vr_file_gz = os.path.join(fol, "vasprun.xml.gz")
 
         if os.path.exists(vr_file):
             filenames.append(vr_file)
         elif os.path.exists(vr_file_gz):
             filenames.append(vr_file_gz)
         else:
-            logging.error('ERROR: No vasprun.xml found in {}!'.format(fol))
+            logging.error("ERROR: No vasprun.xml found in {}!".format(fol))
             sys.exit()
 
     return filenames
@@ -418,31 +485,31 @@ def save_data_files(bs, prefix=None, directory=None):
     Returns:
         The filename of the written data file.
     """
-    filename = '{}_band.dat'.format(prefix) if prefix else 'band.dat'
-    directory = directory if directory else '.'
+    filename = "{}_band.dat".format(prefix) if prefix else "band.dat"
+    directory = directory if directory else "."
     filename = os.path.join(directory, filename)
 
     if bs.is_metal():
         zero = bs.efermi
     else:
-        zero = bs.get_vbm()['energy']
+        zero = bs.get_vbm()["energy"]
 
-    with open(filename, 'w') as f:
-        header = '#k-distance eigenvalue[eV]\n'
+    with open(filename, "w") as f:
+        header = "#k-distance eigenvalue[eV]\n"
         f.write(header)
 
         # write the spin up eigenvalues
         for band in bs.bands[Spin.up]:
             for d, e in zip(bs.distance, band):
-                f.write('{:.8f} {:.8f}\n'.format(d, e - zero))
-            f.write('\n')
+                f.write("{:.8f} {:.8f}\n".format(d, e - zero))
+            f.write("\n")
 
         # calculation is spin polarised, write spin down bands at end of file
         if bs.is_spin_polarized:
             for band in bs.bands[Spin.down]:
                 for d, e in zip(bs.distance, band):
-                    f.write('{:.8f} {:.8f}\n'.format(d, e - zero))
-                f.write('\n')
+                    f.write("{:.8f} {:.8f}\n".format(d, e - zero))
+                f.write("\n")
     return filename
 
 
@@ -463,8 +530,8 @@ def _el_orb_tuple(string):
             `[('Sn', ('s', 'p')), 'O']`
     """
     el_orbs = []
-    for split in string.split(','):
-        splits = split.split('.')
+    for split in string.split(","):
+        splits = split.split(".")
         el = splits[0]
         if len(splits) == 1:
             el_orbs.append(el)
@@ -484,149 +551,285 @@ def _replace_ext(string, new_ext):
         A string with files extension replaced by new_ext
     """
     name, _ = os.path.splitext(string)
-    return name + '.' + new_ext
+    return name + "." + new_ext
 
 
 def _get_parser():
-    parser = argparse.ArgumentParser(description="""
+    parser = argparse.ArgumentParser(
+        description="""
     bandplot is a script to produce publication-ready band
     structure diagrams""",
-                                     epilog="""
+        epilog="""
     Author: {}
     Version: {}
-    Last updated: {}""".format(__author__, __version__, __date__))
+    Last updated: {}""".format(
+            __author__, __version__, __date__
+        ),
+    )
 
-    parser.add_argument('-f', '--filenames', default=None, nargs='+',
-                        metavar='F',
-                        help="one or more vasprun.xml files to plot")
-    parser.add_argument('-c', '--code', default='vasp',
-                        help='Electronic structure code (default: vasp).'
-                             '"questaal" also supported.')
-    parser.add_argument('-p', '--prefix', metavar='P',
-                        help='prefix for the files generated')
-    parser.add_argument('-d', '--directory', metavar='D',
-                        help='output directory for files')
-    parser.add_argument('-b', '--band-edges', dest='band_edges',
-                        action='store_true',
-                        help='highlight the band edges with markers')
-    parser.add_argument('--project', default=None, metavar='S',
-                        type=_el_orb_tuple, dest='projection_selection',
-                        help=('select which orbitals to project onto the band '
-                              'structure (e.g. "Zn.s,Zn.p,O")'))
-    parser.add_argument('--mode', default='rgb', type=str,
-                        help=('mode for orbital projections (options: rgb, '
-                              'stacked)'))
-    parser.add_argument('--normalise', default='rgb', type=str,
-                        help=('how to normalise projections (options: all, '
-                              'select)'))
-    parser.add_argument('--interpolate-factor', type=int, default=4,
-                        dest='interpolate_factor', metavar='N',
-                        help=('interpolate factor for band structure '
-                              'projections (default: 4)'))
-    parser.add_argument('--cartesian', action='store_true',
-                        help='Read cartesian k-point coordinates. This is only'
-                             ' necessary for some Questaal calculations; Vasp '
-                             'outputs are less ambiguous and this option will '
-                             'be ignored if --code=vasp.')
-    parser.add_argument('--circle-size', type=int, default=150,
-                        dest='circle_size', metavar='S',
-                        help=('circle size for "stacked" projections '
-                              '(default: 150)'))
-    parser.add_argument('--ylabel', type=str, default='Energy (eV)',
-                        help='y-axis (i.e. energy) label/units')
-    parser.add_argument('--dos-label', type=str, dest='dos_label',
-                        default=None,
-                        help='Axis label for DOS if included')
-    parser.add_argument('--dos', default=None,
-                        help='path to density of states vasprun.xml')
-    parser.add_argument('--elements', type=_el_orb, metavar='E',
-                        help='elemental orbitals to plot (e.g. "C.s.p,O")')
-    parser.add_argument('--orbitals', type=_el_orb, metavar='O',
-                        help=('orbitals to split into lm-decomposed '
-                              'contributions (e.g. "Ru.d")'))
-    parser.add_argument('--atoms', type=_atoms, metavar='A',
-                        help=('atoms to include (e.g. "O.1.2.3,Ru.1.2.3")'))
-    parser.add_argument('--spin', type=str, default=None,
-                        help=('select only one spin channel for a '
-                              'spin-polarised calculation '
-                              '(options: up, 1; down, -1)'))
-    parser.add_argument('--scissor', type=float, default=None, dest='scissor',
-                        help='apply scissor operator')
-    parser.add_argument('--total-only', action='store_true', dest='total_only',
-                        help='only plot the total density of states')
-    parser.add_argument('--no-total', action='store_false', dest='total',
-                        help='don\'t plot the total density of states')
-    parser.add_argument('--legend-cutoff', type=float, default=3,
-                        dest='legend_cutoff', metavar='C',
-                        help=('cut-off in %% of total DOS that determines if'
-                              ' a line is given a label (default: 3)'))
-    parser.add_argument('-g', '--gaussian', type=float, metavar='G',
-                        help='standard deviation of DOS gaussian broadening')
-    parser.add_argument('--scale', type=float, default=1,
-                        help='scaling factor for the density of states')
-    parser.add_argument('--height', type=float, default=None,
-                        help='height of the graph')
-    parser.add_argument('--width', type=float, default=None,
-                        help='width of the graph')
-    parser.add_argument('--ymin', type=float, default=-6.,
-                        help='minimum energy on the y-axis')
-    parser.add_argument('--ymax', type=float, default=6.,
-                        help='maximum energy on the y-axis')
-    parser.add_argument('--style', type=str, nargs='+', default=None,
-                        help='matplotlib style specifications')
-    parser.add_argument('--no-base-style', action='store_true',
-                        dest='no_base_style',
-                        help='prevent use of sumo base style')
-    parser.add_argument('--config', type=str, default=None,
-                        help='colour configuration file')
-    parser.add_argument('--format', type=str, default='pdf',
-                        dest='image_format', metavar='FORMAT',
-                        help='image file format (options: pdf, svg, jpg, png)')
-    parser.add_argument('--dpi', type=int, default=400,
-                        help='pixel density for image file')
-    parser.add_argument('--font', default=None, help='font to use')
+    parser.add_argument(
+        "-f",
+        "--filenames",
+        default=None,
+        nargs="+",
+        metavar="F",
+        help="one or more vasprun.xml files to plot",
+    )
+    parser.add_argument(
+        "-c",
+        "--code",
+        default="vasp",
+        help="Electronic structure code (default: vasp)." '"questaal" also supported.',
+    )
+    parser.add_argument(
+        "-p", "--prefix", metavar="P", help="prefix for the files generated"
+    )
+    parser.add_argument(
+        "-d", "--directory", metavar="D", help="output directory for files"
+    )
+    parser.add_argument(
+        "-b",
+        "--band-edges",
+        dest="band_edges",
+        action="store_true",
+        help="highlight the band edges with markers",
+    )
+    parser.add_argument(
+        "--project",
+        default=None,
+        metavar="S",
+        type=_el_orb_tuple,
+        dest="projection_selection",
+        help=(
+            "select which orbitals to project onto the band "
+            'structure (e.g. "Zn.s,Zn.p,O")'
+        ),
+    )
+    parser.add_argument(
+        "--mode",
+        default="rgb",
+        type=str,
+        help=("mode for orbital projections (options: rgb, " "stacked)"),
+    )
+    parser.add_argument(
+        "--normalise",
+        default="all",
+        type=str,
+        help=("how to normalise projections (options: all, " "select)"),
+    )
+    parser.add_argument(
+        "--interpolate-factor",
+        type=int,
+        default=4,
+        dest="interpolate_factor",
+        metavar="N",
+        help=("interpolate factor for band structure " "projections (default: 4)"),
+    )
+    parser.add_argument(
+        "--cartesian",
+        action="store_true",
+        help="Read cartesian k-point coordinates. This is only"
+        " necessary for some Questaal calculations; Vasp "
+        "outputs are less ambiguous and this option will "
+        "be ignored if --code=vasp.",
+    )
+    parser.add_argument(
+        "--circle-size",
+        type=int,
+        default=150,
+        dest="circle_size",
+        metavar="S",
+        help=('circle size for "stacked" projections ' "(default: 150)"),
+    )
+    parser.add_argument(
+        "--ylabel",
+        type=str,
+        default="Energy (eV)",
+        help="y-axis (i.e. energy) label/units",
+    )
+    parser.add_argument(
+        "--dos-label",
+        type=str,
+        dest="dos_label",
+        default=None,
+        help="Axis label for DOS if included",
+    )
+    parser.add_argument(
+        "--dos", default=None, help="path to density of states vasprun.xml"
+    )
+    parser.add_argument(
+        "--elements",
+        type=_el_orb,
+        metavar="E",
+        help='elemental orbitals to plot (e.g. "C.s.p,O")',
+    )
+    parser.add_argument(
+        "--orbitals",
+        type=_el_orb,
+        metavar="O",
+        help=("orbitals to split into lm-decomposed " 'contributions (e.g. "Ru.d")'),
+    )
+    parser.add_argument(
+        "--atoms",
+        type=_atoms,
+        metavar="A",
+        help=('atoms to include (e.g. "O.1.2.3,Ru.1.2.3")'),
+    )
+    parser.add_argument(
+        "--spin",
+        type=str,
+        default=None,
+        help=(
+            "select only one spin channel for a "
+            "spin-polarised calculation "
+            "(options: up, 1; down, -1)"
+        ),
+    )
+    parser.add_argument(
+        "--scissor",
+        type=float,
+        default=None,
+        dest="scissor",
+        help="apply scissor operator",
+    )
+    parser.add_argument(
+        "--total-only",
+        action="store_true",
+        dest="total_only",
+        help="only plot the total density of states",
+    )
+    parser.add_argument(
+        "--no-total",
+        action="store_false",
+        dest="total",
+        help="don't plot the total density of states",
+    )
+    parser.add_argument(
+        "--legend-cutoff",
+        type=float,
+        default=3,
+        dest="legend_cutoff",
+        metavar="C",
+        help=(
+            "cut-off in %% of total DOS that determines if"
+            " a line is given a label (default: 3)"
+        ),
+    )
+    parser.add_argument(
+        "-g",
+        "--gaussian",
+        type=float,
+        metavar="G",
+        help="standard deviation of DOS gaussian broadening",
+    )
+    parser.add_argument(
+        "--scale",
+        type=float,
+        default=1,
+        help="scaling factor for the density of states",
+    )
+    parser.add_argument(
+        "--height", type=float, default=None, help="height of the graph"
+    )
+    parser.add_argument("--width", type=float, default=None, help="width of the graph")
+    parser.add_argument(
+        "--ymin", type=float, default=-6.0, help="minimum energy on the y-axis"
+    )
+    parser.add_argument(
+        "--ymax", type=float, default=6.0, help="maximum energy on the y-axis"
+    )
+    parser.add_argument(
+        "--style",
+        type=str,
+        nargs="+",
+        default=None,
+        help="matplotlib style specifications",
+    )
+    parser.add_argument(
+        "--no-base-style",
+        action="store_true",
+        dest="no_base_style",
+        help="prevent use of sumo base style",
+    )
+    parser.add_argument(
+        "--config", type=str, default=None, help="colour configuration file"
+    )
+    parser.add_argument(
+        "--format",
+        type=str,
+        default="pdf",
+        dest="image_format",
+        metavar="FORMAT",
+        help="image file format (options: pdf, svg, jpg, png)",
+    )
+    parser.add_argument(
+        "--dpi", type=int, default=400, help="pixel density for image file"
+    )
+    parser.add_argument("--font", default=None, help="font to use")
     return parser
 
 
 def main():
     args = _get_parser().parse_args()
-    logging.basicConfig(filename='sumo-bandplot.log', level=logging.INFO,
-                        filemode='w', format='%(message)s')
+    logging.basicConfig(
+        filename="sumo-bandplot.log",
+        level=logging.INFO,
+        filemode="w",
+        format="%(message)s",
+    )
     console = logging.StreamHandler()
     logging.info(" ".join(sys.argv[:]))
-    logging.getLogger('').addHandler(console)
+    logging.getLogger("").addHandler(console)
 
     if args.config is None:
-        config_path = resource_filename(Requirement.parse('sumo'),
-                                        'sumo.plotting/orbital_colours.conf')
+        config_path = resource_filename(
+            Requirement.parse("sumo"), "sumo.plotting/orbital_colours.conf"
+        )
     else:
         config_path = args.config
     colours = configparser.ConfigParser()
     colours.read(os.path.abspath(config_path))
 
-    warnings.filterwarnings("ignore", category=UserWarning,
-                            module="matplotlib")
-    warnings.filterwarnings("ignore", category=UnicodeWarning,
-                            module="matplotlib")
-    warnings.filterwarnings("ignore", category=UserWarning,
-                            module="pymatgen")
+    warnings.filterwarnings("ignore", category=UserWarning, module="matplotlib")
+    warnings.filterwarnings("ignore", category=UnicodeWarning, module="matplotlib")
+    warnings.filterwarnings("ignore", category=UserWarning, module="pymatgen")
 
-    bandplot(filenames=args.filenames, code=args.code, prefix=args.prefix,
-             directory=args.directory, vbm_cbm_marker=args.band_edges,
-             projection_selection=args.projection_selection, mode=args.mode,
-             normalise=args.normalise,
-             interpolate_factor=args.interpolate_factor,
-             cart_coords=args.cartesian, scissor=args.scissor,
-             circle_size=args.circle_size, yscale=args.scale,
-             ylabel=args.ylabel, dos_label=args.dos_label,
-             dos_file=args.dos, elements=args.elements,
-             lm_orbitals=args.orbitals, atoms=args.atoms, spin=args.spin,
-             total_only=args.total_only, plot_total=args.total,
-             legend_cutoff=args.legend_cutoff, gaussian=args.gaussian,
-             height=args.height, width=args.width, ymin=args.ymin,
-             style=args.style, no_base_style=args.no_base_style,
-             ymax=args.ymax, colours=colours, image_format=args.image_format,
-             dpi=args.dpi, fonts=args.font)
+    bandplot(
+        filenames=args.filenames,
+        code=args.code,
+        prefix=args.prefix,
+        directory=args.directory,
+        vbm_cbm_marker=args.band_edges,
+        projection_selection=args.projection_selection,
+        mode=args.mode,
+        normalise=args.normalise,
+        interpolate_factor=args.interpolate_factor,
+        cart_coords=args.cartesian,
+        scissor=args.scissor,
+        circle_size=args.circle_size,
+        yscale=args.scale,
+        ylabel=args.ylabel,
+        dos_label=args.dos_label,
+        dos_file=args.dos,
+        elements=args.elements,
+        lm_orbitals=args.orbitals,
+        atoms=args.atoms,
+        spin=args.spin,
+        total_only=args.total_only,
+        plot_total=args.total,
+        legend_cutoff=args.legend_cutoff,
+        gaussian=args.gaussian,
+        height=args.height,
+        width=args.width,
+        ymin=args.ymin,
+        style=args.style,
+        no_base_style=args.no_base_style,
+        ymax=args.ymax,
+        colours=colours,
+        image_format=args.image_format,
+        dpi=args.dpi,
+        fonts=args.font,
+    )
 
 
 if __name__ == "__main__":
